Index: base/i18n/rtl.h |
diff --git a/base/i18n/rtl.h b/base/i18n/rtl.h |
index c80d2f85777e6d31745057381618011fa549d45c..aa5f6810a9b0a8f38b9870fbc862ec8313ccfa29 100644 |
--- a/base/i18n/rtl.h |
+++ b/base/i18n/rtl.h |
@@ -64,7 +64,7 @@ BASE_I18N_EXPORT bool ICUIsRTL(); |
BASE_I18N_EXPORT TextDirection GetTextDirectionForLocale( |
const char* locale_name); |
// Given the string in |text|, returns the directionality of the first |
// character with strong directionality in the string. If no character in the |
// text has strong directionality, LEFT_TO_RIGHT is returned. The Bidi |
// character types L, LRE, LRO, R, AL, RLE, and RLO are considered as strong |
@@ -72,6 +72,8 @@ BASE_I18N_EXPORT TextDirection GetTextDirectionForLocale( |
// for more information. |
BASE_I18N_EXPORT TextDirection GetFirstStrongCharacterDirection( |
const string16& text); |
+BASE_I18N_EXPORT TextDirection GetLastStrongCharacterDirection( |
+ const string16& text); |
// Given the string in |text|, returns LEFT_TO_RIGHT or RIGHT_TO_LEFT if all the |
// strong directionality characters in the string are of the same |
@@ -64,7 +64,7 @@ BASE_I18N_EXPORT bool ICUIsRTL(); |
BASE_I18N_EXPORT TextDirection GetTextDirectionForLocale( |
const char* locale_name); |
-// Given the string in |text|, returns the directionality of the first |
+// Given the string in |text|, returns the directionality of the first or last |
// character with strong directionality in the string. If no character in the |
// text has strong directionality, LEFT_TO_RIGHT is returned. The Bidi |